@@ -1,12 +1,14 @@
 ##from .functionsTab import _FunctionsTab
 from .apiTab import apiTab, startApiConsole
-from .clipitTab import clipitTab, startClipitConsole
+from .imageTab import startImageConsole, imageTab
+from abstract_clipit import clipitTab, startClipitConsole
 from .finderTab import finderConsole, startFinderConsole
 from .logPaneTab import logPaneTab, startLogPaneConsole
 from .appRunnerTab import appRunnerTab, startAppRunnerConsole
 from .reactRunnerTab import reactRunnerTab, startReactRunnerConsole
 from .windowManagerTab import windowManagerTab, startWindowManagerConsole
 from .launcherWindowTab import launcherWindowTab, startLauncherWindowConsole
+
 from abstract_gui.QT6 import QTabWidget,QMainWindow
 from abstract_gui.QT6.utils.console_utils import ConsoleBase
 from abstract_gui.QT6.utils.console_utils import startConsole
@@ -22,5 +24,6 @@ class ideTab(ConsoleBase):
         inner.addTab(apiTab(),   "Api")
         inner.addTab(clipitTab(),   "Clipit")
         inner.addTab(windowManagerTab(),   "Window Mgr")
-        inner.addTab(launcherWindowTab(),   "Launcher")
-        inner.addTab(appRunnerTab(),   "appRunner")
+        inner.addTab(launcherWindowTab(),   "launcherWindow")
+        inner.addTab(imageTab(),   "Images")
+        inner.addTab(logPaneTab(),   "logs")
