@@ -1,4 +1,4 @@
 from consoles import *
 from abstract_gui import *
-startConsole(appRunnerTab)
+startConsole(launcherWindowTab)
 
